Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(553)

Unified Diff: components/policy/core/common/cloud/user_cloud_policy_store_base.h

Issue 2488573003: Expose signing key from cloud policy stores (Closed)
Patch Set: Rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/policy/core/common/cloud/user_cloud_policy_store_base.h
diff --git a/components/policy/core/common/cloud/user_cloud_policy_store_base.h b/components/policy/core/common/cloud/user_cloud_policy_store_base.h
index 7356b5d0f79d4848da4fe89a6f1224ce00346efd..72cfb0069e42aaae45c5dd2cdb8dfd008866fe94 100644
--- a/components/policy/core/common/cloud/user_cloud_policy_store_base.h
+++ b/components/policy/core/common/cloud/user_cloud_policy_store_base.h
@@ -36,10 +36,12 @@ class POLICY_EXPORT UserCloudPolicyStoreBase : public CloudPolicyStore {
std::unique_ptr<enterprise_management::PolicyFetchResponse> policy,
CloudPolicyValidatorBase::ValidateTimestampOption option);
// Sets |policy_data| and |payload| as the active policy.
void InstallPolicy(
std::unique_ptr<enterprise_management::PolicyData> policy_data,
- std::unique_ptr<enterprise_management::CloudPolicySettings> payload);
+ std::unique_ptr<enterprise_management::CloudPolicySettings> payload,
+ const std::string& policy_signature_public_key);
scoped_refptr<base::SequencedTaskRunner> background_task_runner() const {
return background_task_runner_;
@@ -36,10 +36,12 @@ class POLICY_EXPORT UserCloudPolicyStoreBase : public CloudPolicyStore {
std::unique_ptr<enterprise_management::PolicyFetchResponse> policy,
CloudPolicyValidatorBase::ValidateTimestampOption option);
- // Sets |policy_data| and |payload| as the active policy.
+ // Sets |policy_data| and |payload| as the active policy, and sets
+ // |policy_signature_public_key| as the active public key.
void InstallPolicy(
std::unique_ptr<enterprise_management::PolicyData> policy_data,

Powered by Google App Engine
This is Rietveld 408576698